@@ -10,17 +10,17 @@ RDF::Query - An RDF query implementation of SPARQL/RDQL in Perl for use with RDF
 
 =head1 VERSION
 
-This document describes RDF::Query version 2.000, released 18 March 2008.
+This document describes RDF::Query version 2.000_03, released 7 March 2008.
 
 =head1 SYNOPSIS
 
  my $query = new RDF::Query ( $rdql, undef, undef, 'rdql' );
  my @rows = $query->execute( $model );
  
- my $query = new RDF::Query ( $sparql );
+ my $query = new RDF::Query ( $sparql, undef, undef, 'sparql' );
  my $iterator = $query->execute( $model );
  while (my $row = $iterator->next) {
-   print $row->{ var }->as_string;
+   ...
  }
 
 =head1 DESCRIPTION
@@ -29,60 +29,27 @@ RDF::Query allows RDQL and SPARQL queries to be run against an RDF model, return
 of matching results.
 
 See L<http://www.w3.org/TR/rdf-sparql-query/> for more information on SPARQL.
-
 See L<http://www.w3.org/Submission/2004/SUBM-RDQL-20040109/> for more information on RDQL.
 
-=head1 CHANGES IN VERSION 2.000
+=head1 REQUIRES
 
-There are many changes in the code between the 1.x and 2.x releases. Most of these
-changes will only affect queries that should have raised errors in the first place
-(SPARQL parsing, queries that use undefined namespaces, etc.). Beyond these changes,
-however, there are some significant API changes that will affect all users:
+L<RDF::Redland|RDF::Redland> or L<RDF::Core|RDF::Core>
 
-=over 4
+L<Parse::RecDescent|Parse::RecDescent> (for RDF::Core)
 
-=item Use of RDF::Trine objects
+L<LWP|LWP>
 
-All nodes and statements returned by RDF::Query are now RDF::Trine objects
-(more specifically, RDF::Trine::Node and RDF::Trine::Statement objects). This
-differes from RDF::Query 1.x where nodes and statements were of the same type
-as the underlying model (Redland nodes from a Redland model and RDF::Core nodes
-from an RDF::Core model).
+L<DateTime::Format::W3CDTF|DateTime::Format::W3CDTF>
 
-In the past, it was possible to execute a query and not know what type of nodes
-were going to be returned, leading to overly verbose code that required examining
-all nodes and statements with the bridge object. This new API brings consistency
-to both the execution model and client code, greatly simplifying interaction
-with query results.
+L<Scalar::Util|Scalar::Util>
 
-=item Binding Result Values
+L<I18N::LangTags|I18N::LangTags>
 
-Binding result values returned by calling C<< $iterator->next >> are now HASH
-references (instead of ARRAY references), keyed by variable name. Where prior
-code might use this code (modulo model definition and namespace declarations):
+L<Storable|Storable>
 
-  my $sparql = 'SELECT ?name ?homepage WHERE { [ foaf:name ?name ; foaf:homepage ?homepage ] }';
-  my $query = RDF::Query->new( $sparql );
-  my $iterator = $query->execute( $model );
-  while (my $row = $iterator->()) {
-    my ($name, $homepage) = @$row;
-    # ...
-  }
+L<List::Utils|List::Utils>
 
-New code using RDF::Query 2.000 and later should instead use:
-
-  my $sparql = 'SELECT ?name ?homepage WHERE { [ foaf:name ?name ; foaf:homepage ?homepage ] }';
-  my $query = RDF::Query->new( $sparql );
-  my $iterator = $query->execute( $model );
-  while (my $row = $iterator->next) {
-    my $name = $row->{ name };
-    my $homepage = $row->{ homepage };
-    # ...
-  }
-
-(Also notice the new method calling syntax for retrieving rows.)
-
-=back
+L<RDF::Trine::Iterator|RDF::Trine::Iterator>
 
 =cut
 
@@ -101,18 +68,14 @@ use List::Util qw(first);
 use List::MoreUtils qw(uniq);
 use Scalar::Util qw(blessed reftype looks_like_number);
 use DateTime::Format::W3CDTF;
-
-use RDF::Trine 0.104;
 use RDF::Trine::Iterator qw(sgrep smap swatch);
 
-require RDF::Query::Functions;	# (needs to happen at runtime because some of the functions rely on RDF::Query being fully loaded (to call add_hook(), for example))
-								# all the built-in functions including:
+require RDF::Query::Functions;	# all the built-in functions including:
 								#     datatype casting, language ops, logical ops,
 								#     numeric ops, datetime ops, and node type testing
 								# also, custom functions including:
 								#     jena:sha1sum, jena:now, jena:langeq, jena:listMember
 								#     ldodds:Distance, kasei:warn
-use RDF::Query::Expression;
 use RDF::Query::Algebra;
 use RDF::Query::Node;
 use RDF::Query::Parser::RDQL;
@@ -129,7 +92,7 @@ BEGIN {
 	$debug			= DEBUG;
 	$js_debug		= 0;
 	$REVISION		= do { my $REV = (qw$Revision: 306 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
-	$VERSION		= '2.000';
+	$VERSION		= '2.000_03';
 	$DEFAULT_PARSER	= 'sparql';
 }
 
@@ -142,13 +105,10 @@ BEGIN {
 
 =item C<new ( $query, $baseuri, $languri, $lang )>
 
-Returns a new RDF::Query object for the specified C<$query>.
-The query language defaults to SPARQL, but may be set specifically by
-specifying either C<$languri> or C<$lang>, whose acceptable values are:
-
-  $lang: 'rdql', 'sparql', 'tsparql', or 'sparqlp'
-
-  $languri: 'http://www.w3.org/TR/rdf-sparql-query/', or 'http://jena.hpl.hp.com/2003/07/query/RDQL'
+Returns a new RDF::Query object for the query specified.
+The query language used will be set if $languri or $lang
+is passed as the URI or name of the query language, otherwise
+the query defaults to SPARQL.
 
 =cut
 sub new {
@@ -176,6 +136,9 @@ sub new {
 	
 	my $pclass	= $names{ $lang } || $uris{ $languri } || $names{ $DEFAULT_PARSER };
 	my $parser	= $pclass->new();
+#	my $parser	= ($lang eq 'rdql' or $languri eq 'http://jena.hpl.hp.com/2003/07/query/RDQL')
+#				? RDF::Query::Parser::RDQL->new()
+#				: RDF::Query::Parser::SPARQL->new();
 	my $parsed	= $parser->parse( $query, $baseuri );
 	
 	my $ua		= LWP::UserAgent->new( agent => "RDF::Query/${VERSION}" );
@@ -221,10 +184,10 @@ sub new {
 
 =item C<get ( $model )>
 
-Executes the query using the specified model, and returns the first matching row as a LIST of values.
+Executes the query using the specified model,
+and returns the first row found.
 
 =cut
-
 sub get {
 	my $self	= shift;
 	my $stream	= $self->execute( @_ );
@@ -251,6 +214,7 @@ sub execute {
 	
 	$self->{_query_cache}	= {};	# a new scratch hash for each execution.
 	
+	local($::NO_BRIDGE)	= 0;
 	$self->{parsed}	= dclone( $self->{parsed_orig} );
 	my $parsed	= $self->{parsed};
 	
@@ -264,7 +228,7 @@ sub execute {
 	} else {
 		throw RDF::Query::Error::ModelError ( -text => "Could not create a model object." );
 	}
-	
+
 	warn "got bridge $bridge" if ($debug);
 	
 	$self->load_data();
@@ -272,11 +236,6 @@ sub execute {
 	$bridge		= $self->bridge();	# reload the bridge object, because fixup might have changed it.
 	my @vars	= $self->variables( $parsed );
 	
-	my @funcs	= $pattern->referenced_functions;
-	foreach my $f (@funcs) {
-		$self->run_hook( 'http://kasei.us/code/rdf-query/hooks/function_init', $f );
-	}
-	
 	# RUN THE QUERY!
 
 	warn "executing the graph pattern" if ($debug);
@@ -300,8 +259,7 @@ sub execute {
 	} elsif ($parsed->{'method'} eq 'ASK') {
 		$stream	= $self->ask( $stream );
 	}
-	
-	warn "going to call post-execute hook" if ($debug);
+
 	$self->run_hook( 'http://kasei.us/code/rdf-query/hooks/post-execute', $bridge, $stream );
 	
 	if (wantarray) {
@@ -905,7 +863,7 @@ sub call_function {
 	my $uri		= shift;
 	warn "trying to get function from $uri" if ($debug);
 	
-	my $filter			= RDF::Query::Expression::Function->new( $uri, @_ );
+	my $filter			= RDF::Query::Algebra::Expr::Function->new( $uri, @_ );
 	return $filter->evaluate( $self, $bridge, $bound );
 }
 
@@ -1188,7 +1146,7 @@ with C<$uri>, returns a reference to an empty array.
 sub get_hooks {
 	my $self	= shift;
 	my $uri		= shift;
-	my $func	= $self->{'hooks'}{ $uri }
+	my $func	= $self->{'hooks'}{$uri}
 				|| $RDF::Query::hooks{ $uri }
 				|| [];
 	return $func;
@@ -1391,6 +1349,7 @@ Returns the model bridge of the default graph.
 =cut
 
 sub bridge {
+	Carp::confess if ($::NO_BRIDGE);
 	my $self	= shift;
 	if (@_) {
 		$self->{bridge}	= shift;
@@ -1528,44 +1487,7 @@ __END__
 
 =back
 
-=head1 REQUIRES
-
-=over 4
-
-=item * L<RDF::Trine|RDF::Trine>
-
-=item * L<DateTime|DateTime>
-
-=item * L<DateTime::Format::W3CDTF|DateTime::Format::W3CDTF>
-
-=item * L<Error|Error>
-
-=item * L<I18N::LangTags|I18N::LangTags>
-
-=item * L<JSON|JSON>
-
-=item * L<List::Util|List::Util>
-
-=item * L<List::MoreUtils|List::MoreUtils>
-
-=item * L<LWP|LWP>
-
-=item * L<Parse::RecDescent|Parse::RecDescent>
-
-=item * L<Scalar::Util|Scalar::Util>
-
-=item * L<Set::Scalar|Set::Scalar>
-
-=item * L<Storable|Storable>
-
-=item * L<RDF::Redland|RDF::Redland> or L<RDF::Core|RDF::Core> for optional model support.
-
-=back
-
-=head1 DEFINED HOOKS
-
-The following hook URIs are defined and may be used to extend the query engine
-functionality using the C<< add_hook >> method:
+=head1 Defined Hooks
 
 =over 4
 
@@ -1579,15 +1501,37 @@ Args: ( $query, $bridge )
 C<$query> is the RDF::Query object.
 C<$bridge> is the model bridge (RDF::Query::Model::*) object.
 
-=item http://kasei.us/code/rdf-query/hooks/post-execute
+=back
 
-Called immediately before returning a result iterator from the execute method.
+=head1 Supported Built-in Operators and Functions
 
-Args: ( $query, $bridge, $iterator )
+=over 4
 
-C<$query> is the RDF::Query object.
-C<$bridge> is the model bridge (RDF::Query::Model::*) object.
-C<$iterator> is a RDF::Trine::Iterator object.
+=item * REGEX, BOUND, ISURI, ISBLANK, ISLITERAL
+
+=item * Data-typed literals: DATATYPE(string)
+
+=item * Language-typed literals: LANG(string), LANGMATCHES(string, lang)
+
+=item * Casting functions: xsd:dateTime, xsd:string
+
+=item * dateTime-equal, dateTime-greater-than
+
+=back
+
+=head1 TODO
+
+=over 4
+
+=item * Built-in Operators and Functions
+
+L<http://www.w3.org/TR/rdf-sparql-query/#StandardOperations>
+
+Casting functions: xsd:{boolean,double,float,decimal,integer}, rdf:{URIRef,Literal}, STR
+
+XPath functions: numeric-equal, numeric-less-than, numeric-greater-than, numeric-multiply, numeric-divide, numeric-add, numeric-subtract, not, matches
+
+SPARQL operators: bound, isURI, isBlank, isLiteral, str, lang, datatype, logical-or, logical-and
 
 =back
 
