@@ -30,7 +30,7 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 our ($VERSION, $debug, $lang, $languri);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '2.000';
+	$VERSION	= do { my $REV = (qw$Revision: 121 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
 }
 
 ######################################################################
@@ -220,7 +220,7 @@ sub execute {
 	
 	my $expr		= $self->expr;
 	my $bool		= RDF::Query::Node::Resource->new( "sparql:ebv" );
-	my $filter		= RDF::Query::Expression::Function->new( $bool, $expr );
+	my $filter		= RDF::Query::Algebra::Expr::Function->new( $bool, $expr );
 	my $pattern		= $self->pattern;
 	my $stream		= sgrep {
 						my $bound	= $_;
