@@ -16,13 +16,11 @@ use strict;
 use warnings;
 no warnings 'redefine';
 
-use Scalar::Util qw(blessed reftype refaddr looks_like_number);
+use Scalar::Util qw(blessed reftype looks_like_number);
 
-use RDF::Query;
 use RDF::Query::Model::RDFTrine;
 use RDF::Query::Error qw(:try);
 
-use I18N::LangTags;
 use Bloom::Filter;
 use Data::Dumper;
 use MIME::Base64;
@@ -35,7 +33,7 @@ use Carp qw(carp croak confess);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '2.000';
+	$VERSION	= do { my $REV = (qw$Revision: 121 $)[1]; sprintf("%0.3f", 1 + ($REV/1000)) };
 }
 
 ######################################################################
@@ -292,7 +290,7 @@ $RDF::Query::functions{"sparql:logical-or"}	= sub {
 	my ($bool1, $bool2, $error);
 	try {
 		my $arg1 	= $args->();
-		my $func	= RDF::Query::Expression::Function->new( $bool, $arg1 );
+		my $func	= RDF::Query::Algebra::Expr::Function->new( $bool, $arg1 );
 		my $value	= $func->evaluate( $query, $bridge, {} );
 		$bool1		= ($value->literal_value eq 'true') ? 1 : 0;
 	} otherwise {
@@ -301,7 +299,7 @@ $RDF::Query::functions{"sparql:logical-or"}	= sub {
 	};
 	try {
 		my $arg2 	= $args->();
-		my $func	= RDF::Query::Expression::Function->new( $bool, $arg2 );
+		my $func	= RDF::Query::Algebra::Expr::Function->new( $bool, $arg2 );
 		my $value	= $func->evaluate( $query, $bridge, {} );
 		$bool2		= ($value->literal_value eq 'true') ? 1 : 0;
 	} otherwise {
@@ -330,7 +328,7 @@ $RDF::Query::functions{"sparql:logical-and"}	= sub {
 	my ($bool1, $bool2, $error);
 	try {
 		my $arg1 = $args->();
-		my $func	= RDF::Query::Expression::Function->new( $bool, $arg1 );
+		my $func	= RDF::Query::Algebra::Expr::Function->new( $bool, $arg1 );
 		my $value	= $func->evaluate( $query, $bridge, {} );
 		$bool1		= ($value->literal_value eq 'true') ? 1 : 0;
 	} otherwise {
@@ -338,7 +336,7 @@ $RDF::Query::functions{"sparql:logical-and"}	= sub {
 	};
 	try {
 		my $arg2 = $args->();
-		my $func	= RDF::Query::Expression::Function->new( $bool, $arg2 );
+		my $func	= RDF::Query::Algebra::Expr::Function->new( $bool, $arg2 );
 		my $value	= $func->evaluate( $query, $bridge, {} );
 		$bool2		= ($value->literal_value eq 'true') ? 1 : 0;
 	} otherwise {
@@ -508,9 +506,6 @@ $RDF::Query::functions{"sparql:regex"}	= sub {
 	
 	my $text	= $node->literal_value;
 	my $pattern	= $match->literal_value;
-	if (index($pattern, '(?{') != -1 or index($pattern, '(??{') != -1) {
-		throw RDF::Query::Error::FilterEvaluationError ( -text => 'REGEX() called with unsafe ?{} pattern' );
-	}
 	if (@_) {
 		my $data	= shift;
 		my $flags	= $data->literal_value;
@@ -525,25 +520,25 @@ $RDF::Query::functions{"sparql:regex"}	= sub {
 		: RDF::Query::Node::Literal->new('false', undef, 'http://www.w3.org/2001/XMLSchema#boolean');
 };
 
-# # fn:compare
-# $RDF::Query::functions{"http://www.w3.org/2005/04/xpath-functionscompare"}	= sub {
-# 	my $query	= shift;
-# 	my $bridge	= shift;
-# 	my $nodea	= shift;
-# 	my $nodeb	= shift;
-# 	my $cast	= 'sop:str';
-# 	return ($RDF::Query::functions{$cast}->($query, $nodea) cmp $RDF::Query::functions{$cast}->($query, $nodeb));
-# };
-# 
-# # fn:not
-# $RDF::Query::functions{"http://www.w3.org/2005/04/xpath-functionsnot"}	= sub {
-# 	my $query	= shift;
-# 	my $bridge	= shift;
-# 	my $nodea	= shift;
-# 	my $nodeb	= shift;
-# 	my $cast	= 'sop:str';
-# 	return (0 != ($RDF::Query::functions{$cast}->($query, $nodea) cmp $RDF::Query::functions{$cast}->($query, $nodeb)));
-# };
+# fn:compare
+$RDF::Query::functions{"http://www.w3.org/2005/04/xpath-functionscompare"}	= sub {
+	my $query	= shift;
+	my $bridge	= shift;
+	my $nodea	= shift;
+	my $nodeb	= shift;
+	my $cast	= 'sop:str';
+	return ($RDF::Query::functions{$cast}->($query, $nodea) cmp $RDF::Query::functions{$cast}->($query, $nodeb));
+};
+
+# fn:not
+$RDF::Query::functions{"http://www.w3.org/2005/04/xpath-functionsnot"}	= sub {
+	my $query	= shift;
+	my $bridge	= shift;
+	my $nodea	= shift;
+	my $nodeb	= shift;
+	my $cast	= 'sop:str';
+	return (0 != ($RDF::Query::functions{$cast}->($query, $nodea) cmp $RDF::Query::functions{$cast}->($query, $nodeb)));
+};
 
 # fn:matches
 $RDF::Query::functions{"http://www.w3.org/2005/04/xpath-functionsmatches"}	= sub {
@@ -566,7 +561,7 @@ $RDF::Query::functions{"http://www.w3.org/2005/04/xpath-functionsmatches"}	= sub
 	return undef if (index($pattern, '(?{') != -1);
 	return undef if (index($pattern, '(??{') != -1);
 	my $flags	= blessed($f) ? $f->literal_value : '';
-	
+
 	my $matches;
 	if ($flags) {
 		$pattern	= "(?${flags}:${pattern})";
@@ -624,6 +619,7 @@ $RDF::Query::functions{"java:com.hp.hpl.jena.query.function.library.now"}	= sub
 $RDF::Query::functions{"java:com.hp.hpl.jena.query.function.library.langeq"}	= sub {
 	my $query	= shift;
 	my $bridge	= shift;
+	require I18N::LangTags;
 	my $node	= shift;
 	my $lang	= shift;
 	my $litlang	= $node->literal_value_language;
@@ -716,7 +712,7 @@ $RDF::Query::functions{"http://kasei.us/2007/09/functions/warn"}	= sub {
 	my $query	= shift;
 	my $bridge	= shift;
 	my $value	= shift;
-	my $func	= RDF::Query::Expression::Function->new( 'sparql:str', $value );
+	my $func	= RDF::Query::Algebra::Expr::Function->new( 'sparql:str', $value );
 	
 	my $string	= Dumper( $func->evaluate( undef, undef, {} ) );
 	no warnings 'uninitialized';
@@ -732,18 +728,20 @@ $RDF::Query::functions{"http://kasei.us/2007/09/functions/warn"}	= sub {
 		my $query	= shift;
 		my $bridge	= shift;
 		my $stream	= shift;
-		warn "bloom filter got result stream\n" if ($debug);
-		my $nodemap	= $query->{_query_cache}{ $BLOOM_URL }{ 'nodemap' };
-		$stream->add_extra_result_data('bnode-map', $nodemap);
+		if ($query->{_query_cache}{ $BLOOM_URL }{ 'nodemap' }) {
+			foreach my $map (@{ $query->{_query_cache}{ $BLOOM_URL }{ 'nodemap' } }) {
+				my ($node, $string)	= @$map;
+				warn "adding node map: " . $node->as_string . ": " . $string . "\n";
+			}
+		}
 	}
-	push( @{ $RDF::Query::hooks{ 'http://kasei.us/code/rdf-query/hooks/function_init' } }, sub {
+	RDF::Query->add_hook('http://kasei.us/code/rdf-query/hooks/function_init', sub {
 		my $query		= shift;
 		my $function	= shift;
-		if ($function->uri_value eq $BLOOM_URL) {
-			$query->{_query_cache}{ $BLOOM_URL }{ 'nodemap' }	||= {};
+		if ($function eq $BLOOM_URL) {
 			$query->add_hook_once( 'http://kasei.us/code/rdf-query/hooks/post-execute', \&_BLOOM_ADD_NODE_MAP_TO_STREAM, "${BLOOM_URL}#add_node_map" );
 		}
-	} );
+	});
 	$RDF::Query::functions{"http://kasei.us/code/rdf-query/functions/bloom"}	= sub {
 		my $query	= shift;
 		my $bridge	= shift;
@@ -766,8 +764,7 @@ $RDF::Query::functions{"http://kasei.us/2007/09/functions/warn"}	= sub {
 			my $ok	= $bloom->check( $string );
 			warn "-> ok\n" if ($ok and $debug);
 			if ($ok) {
-				my $nodemap	= $query->{_query_cache}{ $BLOOM_URL }{ 'nodemap' };
-				push( @{ $nodemap->{ $value->as_string } }, $string );
+				push( @{ $query->{_query_cache}{ $BLOOM_URL }{ 'nodemap' } }, [ $value, $string ] );
 				return RDF::Query::Node::Literal->new('true', undef, 'http://www.w3.org/2001/XMLSchema#boolean');
 			}
 		}
